@@ -193,7 +193,7 @@ def install(**kwargs):
             importer.uninstall()
     
     # Install new importer
-    sys.meta_path.append(Importer(kwargs))
+    sys.meta_path.insert(0, Importer(kwargs))
 
 
 class Importer(object):
@@ -334,7 +334,7 @@ class Loader(object):
         # Get modification times of these files.
         sourceTime, binTime, binTime2 = getFileModificationTimes(
                                                 sourceName, binName, binName2)
-        
+       
         # Step 1: create binary (compile and copy), update times
         if sourceTime > binTime2:
             self.create_binary(sourceName, binName, binName2)
@@ -381,15 +381,28 @@ class Loader(object):
         build_dir = 'build_py%i%i_%i' % (sys.version_info[0], sys.version_info[1], NBITS)
         base_dir, name = os.path.split(binName)
         binName3 = os.path.join(base_dir, build_dir, name)
+        if not os.path.isdir(os.path.dirname(binName3)):
+            os.makedirs(os.path.dirname(binName3))
         
         try:
             # Try to compile
             compile_error = self.compile_cython(sourceName, build_dir)
             # Try to copy the file
+            if not os.path.isfile(binName3):
+                try:
+                    import sysconfig
+                    abitag = sysconfig.get_config_var('SOABI')
+                    binName3 = binName3.replace('.so', '.'+abitag+'.so')
+                except Exception:
+                    pass
+                if not os.path.isfile(binName3):
+                    print(compile_error)
+                    raise RuntimeError('Could not find %s, was it not compiled?' % binName3)
             if not compile_error:
                 try:
                     shutil.copy2(binName3, binName2)
                 except Exception:
+                    print(compile_error)
                     raise RuntimeError('Could not write %s, is a process holding it?' % binName2)
         finally:
             self.cleanup(os.path.join(base_dir, build_dir))
@@ -490,9 +503,9 @@ class Loader(object):
             # Get numpy headers
             include_dirs.extend(get_numpy_include_dirs())
             
-            # Extra libs (for msvcr90.dll for exampe)            
-            if sys.platform.startswith('win') and paths.pyzo_lib_dir():
-                library_dirs.append(str(paths.pyzo_lib_dir()))
+#             # Extra libs (for msvcr90.dll for exampe)            
+#             if sys.platform.startswith('win') and paths.pyzo_lib_dir():
+#                 library_dirs.append(str(paths.pyzo_lib_dir()))
             
             # Extra extension kwargs?
             extension_kwargs = user_kwargs.get('extension_kwargs',{})
@@ -515,9 +528,11 @@ class Loader(object):
                 ext_modules = ext_modules,
             )
         
-        except BaseException: # also catch system exit
-            msg = traceback.format_exception_only(*sys.exc_info()[:2])
-            raise RuntimeError("Building module %s failed: %s" % (modName, msg))
+        except BaseException as err: # also catch system exit
+            #msg = traceback.format_exception_only(*sys.exc_info()[:2])
+            #raise RuntimeError("Building module %s failed: %s" % (modName, msg))
+            print("Building module %s failed: " % modName)
+            raise
         else:
             print('Successfully compiled cython file: %s' % modName)
         finally:
